==> easyaspymutations-0.0.1.tar.gz: easyaspymutations-0.0.1/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', 'pysam', 'pandas']

test_requirements = ['pytest>=3', ]

setup(
    author="Sam El-Kamand",
    author_email='selkamand@ccia.org.au',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Assorted utility functions for working with mutation files (vcfs/mafs/etc)",
    entry_points={
        'console_scripts': [
            'easyaspymutations=easyaspymutations.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='easyaspymutations',
    name='easyaspymutations',
    packages=find_packages(include=['easyaspymutations', 'easyaspymutations.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/selkmand/easyaspymutations',
    version='0.0.1',
    zip_safe=False,
)

==> easyaspymutations-0.0.2.tar.gz: easyaspymutations-0.0.2/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', 'pysam', 'pandas', 'sys', 'os']

test_requirements = ['pytest>=3', ]

setup(
    author="Sam El-Kamand",
    author_email='selkamand@ccia.org.au',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Assorted utility functions for working with mutation files (vcfs/mafs/etc)",
    entry_points={
        'console_scripts': [
            'easyaspymutations=easyaspymutations.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='easyaspymutations',
    name='easyaspymutations',
    packages=find_packages(include=['easyaspymutations', 'easyaspymutations.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/selkmand/easyaspymutations',
    version='0.0.2',
    zip_safe=False,
)
